==> elgg-2.3.4.zip: elgg-2.3.4/mod/groups/languages/de.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'groups' => "Gruppen",
	'groups:owned' => "Von mir gegründete Gruppen",
	'groups:owned:user' => 'Gruppen gegründet von %s',
	'groups:yours' => "Meine Gruppen",
	'groups:user' => "Gruppen von %s",
	'groups:all' => "Alle Gruppen",
	'groups:add' => "Starte eine neue Gruppe",
	'groups:edit' => "Bearbeite Gruppen-Einstellungen",
	'groups:delete' => 'Lösche Gruppe',
	'groups:membershiprequests' => 'Verwalte Beitritts-Anfragen',
	'groups:membershiprequests:pending' => 'Verwalte Beitritts-Anfragen (%s)',
	'groups:invitations' => 'Einladungen zum Gruppenbeitritt',
	'groups:invitations:pending' => 'Einladungen zum Gruppenbeitritt (%s)',

	'groups:icon' => 'Gruppen-Icon (leer lassen, um nicht zu ändern)',
	'groups:name' => 'Gruppenname',
	'groups:username' => 'Kurzname der Gruppe (angezeigt in URLs, nur alphanumerische Zeichen)',
	'groups:description' => 'Beschreibung',
	'groups:briefdescription' => 'Kurzbeschreibung',
	'groups:interests' => 'Tags',
	'groups:website' => 'Webseite',
	'groups:members' => 'Gruppen-Mitglieder',
	'groups:my_status' => 'Mein Status',
	'groups:my_status:group_owner' => 'Die Gruppe wurde von Dir gegründet.',
	'groups:my_status:group_member' => 'Du bist Mitglied dieser Gruppe.',
	'groups:subscribed' => 'Benachrichtigungen für diese Gruppe sind aktiviert.',
	'groups:unsubscribed' => 'Benachrichtigungen für diese Gruppe sind deaktiviert.',

	'groups:members:title' => 'Mitglieder von %s',
	'groups:members:more' => "Alle Mitglieder auflisten",
	'groups:membership' => "Beschränkung des Gruppenbeitritts",
	'groups:content_access_mode' => "Zugriffsberechtigung für Inhalte der Gruppe",
	'groups:content_access_mode:warning' => "Warnung: eine Änderung dieser Einstellung verändert nicht die Zugangsberechtigungen für schon existierende Inhalte der Gruppe.",
	'groups:content_access_mode:unrestricted' => "Ohne Beschränkung - Zugriffsbeschränkung allein durch inhaltsspezifischen Zugangslevel",
	'groups:content_access_mode:membersonly' => "Nur Mitglieder - Inhalte der Gruppe für andere nicht zugänglich",
	'groups:access' => "Zugangslevel",
	'groups:owner' => "Gründer",
	'groups:owner:warning' => "Warnung: wenn Du diesen Wert veränderst, bist Du nicht länger der Gründer dieser Gruppe.",
	'groups:widget:num_display' => 'Anzahl der anzuzeigenden Gruppen',
	'groups:widget:membership' => 'Gruppen-Mitgliedschaft',
	'groups:widgets:description' => 'Auflistung der Gruppen, in denen Du Mitglied bist, in Deinem Profil',

	'groups:widget:group_activity:title' => 'Gruppen-Aktivität',
	'groups:widget:group_activity:description' => 'Zeige die Aktivitäten in einer Deiner Gruppen an.',
	'groups:widget:group_activity:edit:select' => 'Wähle eine Gruppe',
	'groups:widget:group_activity:content:noactivity' => 'In dieser Gruppe gibt es noch keine Aktivitäten.',
	'groups:widget:group_activity:content:noselect' => 'Bearbeite dieses Widget, um eine Gruppe auszuwählen.',

	'groups:noaccess' => 'Zugang zur Gruppe verweigert',
	'groups:ingroup' => 'in der Gruppe',
	'groups:cantcreate' => 'Du kannst keine Gruppe erstellen. Dies können nur Administratoren.',
	'groups:cantedit' => 'Du kannst die Gruppen-Einstellungen nicht bearbeiten',
	'groups:saved' => 'Gruppe angelegt',
	'groups:save_error' => 'Beim Anlegen der Gruppe ist ein Fehler aufgetreten.',
	'groups:featured' => 'Besondere Gruppen',
	'groups:makeunfeatured' => 'Aus "Besondere Gruppen" entfernen',
	'groups:makefeatured' => 'Zu "Besondere Gruppen" hinzufügen',
	'groups:featuredon' => '%s ist nun eine "Besondere Gruppe".',
	'groups:unfeatured' => '%s wurde aus der Liste der "Besonderen Gruppen" entfernt.',
	'groups:featured_error' => 'Ungültige Gruppe.',
	'groups:nofeatured' => 'Keine "Besonderen Gruppen" vorhanden.',
	'groups:joinrequest' => 'Gruppenbeitritt beantragen',
	'groups:join' => 'Gruppe beitreten',
	'groups:leave' => 'Gruppe verlassen',
	'groups:invite' => 'Freunde einladen',
	'groups:invite:title' => 'Lade Deine Freunde ein, dieser Gruppe beizutreten',
	'groups:inviteto' => "Freunde zur Gruppe '%s' einladen",
	'groups:nofriends' => "Alle Deine Freunde wurden bereits zu dieser Gruppe eingeladen.",
	'groups:nofriendsatall' => 'Du hast leider noch keine Freunde, die Du einladen könntest!',
	'groups:viagroups' => "via Gruppen",
	'groups:group' => "Gruppe",
	'groups:search:tags' => "Tag",
	'groups:search:title' => "Suche nach Gruppen mit dem Tag '%s'",
	'groups:search:none' => "Es wurden keine passenden Gruppen gefunden.",
	'groups:search_in_group' => "In dieser Gruppe suchen",
	'groups:acl' => "Gruppe: %s",

	'groups:activity' => "Letzte Aktivitäten der Gruppe",
	'groups:enableactivity' => 'Anzeige von "Letzte Aktivitäten der Gruppe" aktivieren',
	'groups:activity:none' => "In dieser Gruppe gibt es noch keine Aktivitäten.",

	'groups:notfound' => "Gruppe nicht gefunden",
	'groups:notfound:details' => "Die angeforderte Gruppe existiert entweder nicht oder Du hast keine Zugangsberechtigung",

	'groups:requests:none' => 'Derzeit gibt es keine ausstehenden Anfragen für einen Beitritt zu dieser Gruppe.',

	'groups:invitations:none' => 'Derzeit gibt es keine unbeantworteten Einladungen zum Beitreten in diese Gruppe.',

	'groups:count' => "Verfügbare Gruppen",
	'groups:open' => "Öffentliche Gruppe",
	'groups:closed' => "Nicht-öffentliche Gruppe",
	'groups:member' => "Mitglieder",
	'groups:searchtag' => "Suche nach Gruppen via Tags",

	'groups:more' => 'Weitere Gruppen',
	'groups:none' => 'Keine Gruppen',

	/**
	 * Access
	 */
	'groups:access:private' => 'Nicht-öffentliche Gruppe - Gruppenbeitritt ist nur mit Einladung möglich',
	'groups:access:public' => 'Öffentliche Gruppe - jeder Benutzer kann der Gruppe beitreten',
	'groups:access:group' => 'Nur für Gruppenmitglieder',
	'groups:closedgroup' => "Diese Gruppe ist nicht-öffentlich.",
	'groups:closedgroup:request' => 'Um dieser Gruppe beitreten zu dürfen, wähle bitte den Menueintrag "Gruppenbeitritt beantragen".',
	'groups:closedgroup:membersonly' => "Diese Gruppe ist nicht-öffentlich und ihr Inhalt ist nur für Gruppenmitglieder zugänglich.",
	'groups:opengroup:membersonly' => "Der Inhalt dieser Gruppe ist nur für Gruppenmitglieder zugännglich.",
	'groups:opengroup:membersonly:join' => 'Um dieser Gruppe beizutreten, wähle bitte den Menueintrag "Gruppe beitreten".',
	'groups:visibility' => 'Wer kann diese Gruppe sehen?',

	/**
	 * Group tools
	 */
	'groups:lastupdated' => '%s zuletzt aktualisiert durch %s',
	'groups:lastcomment' => '%s zuletzt kommentiert durch %s',

	'admin:groups' => 'Gruppen',

	'groups:privategroup' => 'Dies ist eine nicht-öffentliche Gruppe. Der Beitritt zur Gruppe ist nur auf Anfrage möglich.',
	'groups:notitle' => 'Gruppen müssen einen Titel haben.',
	'groups:cantjoin' => 'Du kannst dieser Gruppe nicht beitreten.',
	'groups:cantleave' => 'Das Verlassen der Gruppe ist fehlgeschlagen.',
	'groups:removeuser' => 'Aus der Gruppe entfernen',
	'groups:cantremove' => 'Der Benutzer konnte nicht aus der Gruppe entfernt werden.',
	'groups:removed' => '%s wurde aus der Gruppe entfernt.',
	'groups:addedtogroup' => 'Der Benutzer wurde als Mitglied der Gruppe hinzugefügt.',
	'groups:joinrequestnotmade' => 'Die Anfrage zum Beitritt zur Gruppe ist fehlgeschlagen.',
	'groups:joinrequestmade' => 'Die Anfrage zum Beitritt zur Gruppe wurde gesendet.',
	'groups:joined' => 'Du bist der Gruppe beigetreten!',
	'groups:left' => 'Du hast die Gruppe verlassen.',
	'groups:notowner' => 'Entschuldigung, aber Du bist nicht der Gründer dieser Gruppe.',
	'groups:notmember' => 'Entschuldigung, aber Du bist kein Mitglied dieser Gruppe.',
	'groups:alreadymember' => 'Du bist bereits ein Mitglied dieser Gruppe!',
	'groups:userinvited' => 'Der Benutzer wurde eingeladen.',
	'groups:usernotinvited' => 'Die Einladung an den Benutzer konnte nicht gesendet werden.',
	'groups:useralreadyinvited' => 'Dieser Benutzer wurde bereits eingeladen.',
	'groups:invite:subject' => "Hallo %s, Du wurdest eingeladen, der Gruppe %s beizutreten!",
	'groups:started' => "Gestartet von %s",
	'groups:joinrequest:remove:check' => 'Bist Du sicher, dass Du diese Anfrage zum Gruppenbeitritt löschen willst?',
	'groups:invite:remove:check' => 'Bist Du sicher, dass Du diese Einladung zum Gruppenbeitritt löschen willst?',
	'groups:invite:body' => "Hallo %s,

%s hat Dich eingeladen, der Gruppe '%s' beizutreten. Folge dem Link um Deine ausstehenden Einladungen zum Beitreten in Gruppen zu sehen:

%s",

	'groups:welcome:subject' => "Willkommen in der Gruppe %s!",
	'groups:welcome:body' => "Hallo %s!

Du bist nun ein Mitglied der Gruppe '%s'! Folge dem Link um einen Beitrag in der Gruppe zu schreiben!

%s",

	'groups:request:subject' => "%s hat beantragt, der Gruppe %s beitreten zu dürfen",
	'groups:request:body' => "Hallo %s,

%s hat beantragt, der Gruppe %s beitreten zu dürfen. Folge dem Link um ihr/sein Profil zu sehen:

%s

oder folge dem nächsten Link, um die ausstehenden Anfragen zum Gruppenbeitritt zu sehen:

%s",

	/**
	 * Forum river items
	 */

	'river:create:group:default' => '%s hat die Gruppe %s gegründet',
	'river:join:group:default' => '%s ist der Gruppe %s beigetreten',

	'groups:nowidgets' => 'Für diese Gruppe wurden keine Widgets aktiviert.',


	'groups:widgets:members:title' => 'Mitglieder der Gruppen',
	'groups:widgets:members:description' => 'Zeige die Mitglieder einer Gruppe an.',
	'groups:widgets:members:label:displaynum' => 'Zeige die Mitglieder einer Gruppe an.',
	'groups:widgets:members:label:pleaseedit' => 'Bitte konfiguriere dieses Widget.',

	'groups:widgets:entities:title' => "Objekte in der Gruppe",
	'groups:widgets:entities:description' => "Zeige die Objekte an, die in dieser Gruppe gespeichert sind.",
	'groups:widgets:entities:label:displaynum' => 'Zeige die Objekte einer Gruppe an.',
	'groups:widgets:entities:label:pleaseedit' => 'Bitte konfiguriere dieses Widget.',

	'groups:allowhiddengroups' => 'Möchtest Du private (versteckte) Gruppen zulassen?',
	'groups:whocancreate' => 'Wer soll neue Gruppen erstellen dürfen?',

	/**
	 * Action messages
	 */
	'group:deleted' => 'Die Gruppe und der Inhalt der Gruppe wurde gelöscht.',
	'group:notdeleted' => 'Die Gruppe konnte nicht gelöscht werden.',

	'group:notfound' => 'Die Gruppe wurde nicht gefunden.',
	'groups:deletewarning' => "Bist Du sicher, dass Du diese Gruppe löschen willst? Dies kann nicht rückgängig gemacht werden!",

	'groups:invitekilled' => 'Die Einladung wurde gelöscht.',
	'groups:joinrequestkilled' => 'Der Antrag zum Gruppenbeitritt wurde gelöscht.',
	'groups:error:addedtogroup' => "Das Hinzufügen von %s als Mitglied der Gruppe ist fehlgeschlagen.",
	'groups:add:alreadymember' => "%s ist bereits ein Mitglied dieser Gruppe.",

	/**
	 * ecml
	 */
	'groups:ecml:groupprofile' => 'Gruppen-Profile',
);

==> elgg-2.3.6.zip: elgg-2.3.6/mod/groups/languages/de.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'groups' => "Gruppen",
	'groups:owned' => "Von mir gegründete Gruppen",
	'groups:owned:user' => 'Gruppen gegründet von %s',
	'groups:yours' => "Meine Gruppen",
	'groups:user' => "Gruppen von %s",
	'groups:all' => "Alle Gruppen",
	'groups:add' => "Starte eine neue Gruppe",
	'groups:edit' => "Bearbeite Gruppen-Einstellungen",
	'groups:delete' => 'Lösche Gruppe',
	'groups:membershiprequests' => 'Verwalte Beitritts-Anfragen',
	'groups:membershiprequests:pending' => 'Verwalte Beitritts-Anfragen (%s)',
	'groups:invitations' => 'Einladungen zum Gruppenbeitritt',
	'groups:invitations:pending' => 'Einladungen zum Gruppenbeitritt (%s)',

	'groups:icon' => 'Gruppen-Icon (leer lassen, um nicht zu ändern)',
	'groups:name' => 'Gruppenname',
	'groups:username' => 'Kurzname der Gruppe (angezeigt in URLs, nur alphanumerische Zeichen)',
	'groups:description' => 'Beschreibung',
	'groups:briefdescription' => 'Kurzbeschreibung',
	'groups:interests' => 'Tags',
	'groups:website' => 'Webseite',
	'groups:members' => 'Gruppen-Mitglieder',
	'groups:my_status' => 'Mein Status',
	'groups:my_status:group_owner' => 'Die Gruppe wurde von Dir gegründet.',
	'groups:my_status:group_member' => 'Du bist Mitglied dieser Gruppe.',
	'groups:subscribed' => 'Benachrichtigungen für diese Gruppe sind aktiviert.',
	'groups:unsubscribed' => 'Benachrichtigungen für diese Gruppe sind deaktiviert.',

	'groups:members:title' => 'Mitglieder von %s',
	'groups:members:more' => "Alle Mitglieder auflisten",
	'groups:membership' => "Beschränkung des Gruppenbeitritts",
	'groups:content_access_mode' => "Zugriffsberechtigung für Inhalte der Gruppe",
	'groups:content_access_mode:warning' => "Warnung: eine Änderung dieser Einstellung verändert nicht die Zugangsberechtigungen für schon existierende Inhalte der Gruppe.",
	'groups:content_access_mode:unrestricted' => "Ohne Beschränkung - Zugriffsbeschränkung allein durch inhaltsspezifischen Zugangslevel",
	'groups:content_access_mode:membersonly' => "Nur Mitglieder - Inhalte der Gruppe für andere nicht zugänglich",
	'groups:access' => "Zugangslevel",
	'groups:owner' => "Gründer",
	'groups:owner:warning' => "Warnung: wenn Du diesen Wert veränderst, bist Du nicht länger der Gründer dieser Gruppe.",
	'groups:widget:num_display' => 'Anzahl der anzuzeigenden Gruppen',
	'groups:widget:membership' => 'Gruppen-Mitgliedschaft',
	'groups:widgets:description' => 'Auflistung der Gruppen, in denen Du Mitglied bist, in Deinem Profil',

	'groups:widget:group_activity:title' => 'Gruppen-Aktivität',
	'groups:widget:group_activity:description' => 'Zeige die Aktivitäten in einer Deiner Gruppen an.',
	'groups:widget:group_activity:edit:select' => 'Wähle eine Gruppe',
	'groups:widget:group_activity:content:noactivity' => 'In dieser Gruppe gibt es noch keine Aktivitäten.',
	'groups:widget:group_activity:content:noselect' => 'Bearbeite dieses Widget, um eine Gruppe auszuwählen.',

	'groups:noaccess' => 'Zugang zur Gruppe verweigert',
	'groups:ingroup' => 'in der Gruppe',
	'groups:cantcreate' => 'Du kannst keine Gruppe erstellen. Dies können nur Administratoren.',
	'groups:cantedit' => 'Du kannst die Gruppen-Einstellungen nicht bearbeiten',
	'groups:saved' => 'Gruppe angelegt',
	'groups:save_error' => 'Beim Anlegen der Gruppe ist ein Fehler aufgetreten.',
	'groups:featured' => 'Besondere Gruppen',
	'groups:makeunfeatured' => 'Aus "Besondere Gruppen" entfernen',
	'groups:makefeatured' => 'Zu "Besondere Gruppen" hinzufügen',
	'groups:featuredon' => '%s ist nun eine "Besondere Gruppe".',
	'groups:unfeatured' => '%s wurde aus der Liste der "Besonderen Gruppen" entfernt.',
	'groups:featured_error' => 'Ungültige Gruppe.',
	'groups:nofeatured' => 'Keine "Besonderen Gruppen" vorhanden.',
	'groups:joinrequest' => 'Gruppenbeitritt beantragen',
	'groups:join' => 'Gruppe beitreten',
	'groups:leave' => 'Gruppe verlassen',
	'groups:invite' => 'Freunde einladen',
	'groups:invite:title' => 'Lade Deine Freunde ein, dieser Gruppe beizutreten',
	'groups:inviteto' => "Freunde zur Gruppe '%s' einladen",
	'groups:nofriends' => "Alle Deine Freunde wurden bereits zu dieser Gruppe eingeladen.",
	'groups:nofriendsatall' => 'Du hast leider noch keine Freunde, die Du einladen könntest!',
	'groups:viagroups' => "via Gruppen",
	'groups:group' => "Gruppe",
	'groups:search:tags' => "Tag",
	'groups:search:title' => "Suche nach Gruppen mit dem Tag '%s'",
	'groups:search:none' => "Es wurden keine passenden Gruppen gefunden.",
	'groups:search_in_group' => "In dieser Gruppe suchen",
	'groups:acl' => "Gruppe: %s",

	'groups:activity' => "Letzte Aktivitäten der Gruppe",
	'groups:enableactivity' => 'Anzeige von "Letzte Aktivitäten der Gruppe" aktivieren',
	'groups:activity:none' => "In dieser Gruppe gibt es noch keine Aktivitäten.",

	'groups:notfound' => "Gruppe nicht gefunden",
	'groups:notfound:details' => "Die angeforderte Gruppe existiert entweder nicht oder Du hast keine Zugangsberechtigung",

	'groups:requests:none' => 'Derzeit gibt es keine ausstehenden Anfragen für einen Beitritt zu dieser Gruppe.',

	'groups:invitations:none' => 'Derzeit gibt es keine unbeantworteten Einladungen zum Beitreten in diese Gruppe.',

	'groups:count' => "Verfügbare Gruppen",
	'groups:open' => "Öffentliche Gruppe",
	'groups:closed' => "Nicht-öffentliche Gruppe",
	'groups:member' => "Mitglieder",
	'groups:searchtag' => "Suche nach Gruppen via Tags",

	'groups:more' => 'Weitere Gruppen',
	'groups:none' => 'Keine Gruppen',

	/**
	 * Access
	 */
	'groups:access:private' => 'Nicht-öffentliche Gruppe - Gruppenbeitritt ist nur mit Einladung möglich',
	'groups:access:public' => 'Öffentliche Gruppe - jeder Benutzer kann der Gruppe beitreten',
	'groups:access:group' => 'Nur für Gruppenmitglieder',
	'groups:closedgroup' => "Diese Gruppe ist nicht-öffentlich.",
	'groups:closedgroup:request' => 'Um dieser Gruppe beitreten zu dürfen, wähle bitte den Menueintrag "Gruppenbeitritt beantragen".',
	'groups:closedgroup:membersonly' => "Diese Gruppe ist nicht-öffentlich und ihr Inhalt ist nur für Gruppenmitglieder zugänglich.",
	'groups:opengroup:membersonly' => "Der Inhalt dieser Gruppe ist nur für Gruppenmitglieder zugännglich.",
	'groups:opengroup:membersonly:join' => 'Um dieser Gruppe beizutreten, wähle bitte den Menueintrag "Gruppe beitreten".',
	'groups:visibility' => 'Wer kann diese Gruppe sehen?',

	/**
	 * Group tools
	 */
	'groups:lastupdated' => '%s zuletzt aktualisiert durch %s',
	'groups:lastcomment' => '%s zuletzt kommentiert durch %s',

	'admin:groups' => 'Gruppen',

	'groups:privategroup' => 'Dies ist eine nicht-öffentliche Gruppe. Der Beitritt zur Gruppe ist nur auf Anfrage möglich.',
	'groups:notitle' => 'Gruppen müssen einen Titel haben.',
	'groups:cantjoin' => 'Du kannst dieser Gruppe nicht beitreten.',
	'groups:cantleave' => 'Das Verlassen der Gruppe ist fehlgeschlagen.',
	'groups:removeuser' => 'Aus der Gruppe entfernen',
	'groups:cantremove' => 'Der Benutzer konnte nicht aus der Gruppe entfernt werden.',
	'groups:removed' => '%s wurde aus der Gruppe entfernt.',
	'groups:addedtogroup' => 'Der Benutzer wurde als Mitglied der Gruppe hinzugefügt.',
	'groups:joinrequestnotmade' => 'Die Anfrage zum Beitritt zur Gruppe ist fehlgeschlagen.',
	'groups:joinrequestmade' => 'Die Anfrage zum Beitritt zur Gruppe wurde gesendet.',
	'groups:joinrequest:exists' => 'Du hast bereits eine Anfrage zum Beitritt zu dieser Gruppe gestellt.',
	'groups:joined' => 'Du bist der Gruppe beigetreten!',
	'groups:left' => 'Du hast die Gruppe verlassen.',
	'groups:notowner' => 'Entschuldigung, aber Du bist nicht der Gründer dieser Gruppe.',
	'groups:notmember' => 'Entschuldigung, aber Du bist kein Mitglied dieser Gruppe.',
	'groups:alreadymember' => 'Du bist bereits ein Mitglied dieser Gruppe!',
	'groups:userinvited' => 'Der Benutzer wurde eingeladen.',
	'groups:usernotinvited' => 'Die Einladung an den Benutzer konnte nicht gesendet werden.',
	'groups:useralreadyinvited' => 'Dieser Benutzer wurde bereits eingeladen.',
	'groups:invite:subject' => "Hallo %s, Du wurdest eingeladen, der Gruppe %s beizutreten!",
	'groups:started' => "Gestartet von %s",
	'groups:joinrequest:remove:check' => 'Bist Du sicher, dass Du diese Anfrage zum Gruppenbeitritt löschen willst?',
	'groups:invite:remove:check' => 'Bist Du sicher, dass Du diese Einladung zum Gruppenbeitritt löschen willst?',
	'groups:invite:body' => "Hallo %s,

%s hat Dich eingeladen, der Gruppe '%s' beizutreten. Folge dem Link um Deine ausstehenden Einladungen zum Beitreten in Gruppen zu sehen:

%s",

	'groups:welcome:subject' => "Willkommen in der Gruppe %s!",
	'groups:welcome:body' => "Hallo %s!

Du bist nun ein Mitglied der Gruppe '%s'! Folge dem Link um einen Beitrag in der Gruppe zu schreiben!

%s",

	'groups:request:subject' => "%s hat beantragt, der Gruppe %s beitreten zu dürfen",
	'groups:request:body' => "Hallo %s,

%s hat beantragt, der Gruppe %s beitreten zu dürfen. Folge dem Link um ihr/sein Profil zu sehen:

%s

oder folge dem nächsten Link, um die ausstehenden Anfragen zum Gruppenbeitritt zu sehen:

%s",

	/**
	 * Forum river items
	 */

	'river:create:group:default' => '%s hat die Gruppe %s gegründet',
	'river:join:group:default' => '%s ist der Gruppe %s beigetreten',

	'groups:nowidgets' => 'Für diese Gruppe wurden keine Widgets aktiviert.',


	'groups:widgets:members:title' => 'Mitglieder der Gruppen',
	'groups:widgets:members:description' => 'Zeige die Mitglieder einer Gruppe an.',
	'groups:widgets:members:label:displaynum' => 'Zeige die Mitglieder einer Gruppe an.',
	'groups:widgets:members:label:pleaseedit' => 'Bitte konfiguriere dieses Widget.',

	'groups:widgets:entities:title' => "Objekte in der Gruppe",
	'groups:widgets:entities:description' => "Zeige die Objekte an, die in dieser Gruppe gespeichert sind.",
	'groups:widgets:entities:label:displaynum' => 'Zeige die Objekte einer Gruppe an.',
	'groups:widgets:entities:label:pleaseedit' => 'Bitte konfiguriere dieses Widget.',

	'groups:allowhiddengroups' => 'Möchtest Du private (versteckte) Gruppen zulassen?',
	'groups:whocancreate' => 'Wer soll neue Gruppen erstellen dürfen?',

	/**
	 * Action messages
	 */
	'group:deleted' => 'Die Gruppe und der Inhalt der Gruppe wurde gelöscht.',
	'group:notdeleted' => 'Die Gruppe konnte nicht gelöscht werden.',

	'group:notfound' => 'Die Gruppe wurde nicht gefunden.',
	'groups:deletewarning' => "Bist Du sicher, dass Du diese Gruppe löschen willst? Dies kann nicht rückgängig gemacht werden!",

	'groups:invitekilled' => 'Die Einladung wurde gelöscht.',
	'groups:joinrequestkilled' => 'Der Antrag zum Gruppenbeitritt wurde gelöscht.',
	'groups:error:addedtogroup' => "Das Hinzufügen von %s als Mitglied der Gruppe ist fehlgeschlagen.",
	'groups:add:alreadymember' => "%s ist bereits ein Mitglied dieser Gruppe.",

	/**
	 * ecml
	 */
	'groups:ecml:groupprofile' => 'Gruppen-Profile',
);
